@@ -1,5 +1,10 @@
 import requests
+
+from myPackage.libPackage2.getCountriesByName import getCountriesByName
+
+
 class getCities:
+    message = ""
     def getCitiesPopOver(self):
         url = "https://wft-geo-db.p.rapidapi.com/v1/geo/cities"
         querystring = {"minPopulation":"20000000"}
@@ -10,7 +15,14 @@ class getCities:
         response = requests.request("GET", url, headers=headers, params=querystring)
         city = response.json()
         print([i['city'] for i in city['data']])
+        global message
+        message = [i['city'] for i in city['data']]
+    def getMessage(self):
+        global message
+        return message
 def main():
-    print("działa")
+    countries = getCountriesByName("r")
+    countries.getCitiesByLetter()
+    print(countries.getMessage())
 if __name__ == '__main__':
     main();
\ No newline at end of file
