@@ -2,6 +2,7 @@ import time
 
 import requests
 class getCountries:
+    message = ""
     def getCountries(self):
         for x in range(19):
             offset=x*10
@@ -18,4 +19,9 @@ class getCountries:
             countries = response.json()
             time.sleep(1.5)
             print([i['name'] for i in countries['data']])
+            global message
+            message = [i['name'] for i in countries['data']] + message
             i=0;
+    def getMessage(self):
+        global message
+        return message
\ No newline at end of file
